'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _extends = _interopDefault(require('@babel/runtime/helpers/extends'));
var _defineProperty = _interopDefault(require('@babel/runtime/helpers/defineProperty'));
var _objectWithoutProperties = _interopDefault(require('@babel/runtime/helpers/objectWithoutProperties'));
var core = require('@westpac/core');
var PropTypes = _interopDefault(require('prop-types'));
require('@babel/runtime/helpers/taggedTemplateLiteral');
var body = require('@westpac/body');

// Component
// ==============================

var Well = function Well(_ref) {
  var tag = _ref.state.tag,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx(body.Body, _extends({
    tag: tag
  }, rest));
};
// Styles
// ==============================


var wellStyles = function wellStyles() {
  var mq = core.useMediaQuery();

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS,
      SPACING = _useBrand.SPACING;

  return mq({
    label: core.getLabel('well'),
    padding: [SPACING(2), null, SPACING(4)],
    marginBottom: SPACING(3),
    backgroundColor: COLORS.light,
    border: "1px solid ".concat(COLORS.border),
    borderRadius: '0.1875rem',
    // Nested Well styling
    '& > &': {
      backgroundColor: '#fff',
      margin: "".concat(SPACING(2), " 0")
    }
  })[0];
}; // ==============================
// Attributes
// ==============================


var wellAttributes = function wellAttributes() {
  return null;
}; // ==============================
// Exports
// ==============================


var defaultWell = {
  component: Well,
  styles: wellStyles,
  attributes: wellAttributes
};

var pkg = {
	name: "@westpac/well",
	version: "1.0.0",
	description: "Well component for the Westpac GEL Design System",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/well",
	blender: {
		recipe: "blender/recipe.js"
	},
	components: [
		{
			name: "Well",
			src: "Well.js"
		}
	],
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	license: "GPL-3.0+",
	scripts: {
		start: "PACKAGE_NAME=well webpack-dev-server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:all": "yarn test:integration",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	main: "dist/well.cjs.js",
	module: "dist/well.esm.js",
	dependencies: {
		"@babel/runtime": "^7.9.6",
		"@westpac/body": "^1.2.0",
		"@westpac/core": "^1.1.0",
		"prop-types": "^15.7.2"
	},
	peerDependencies: {
		react: "^16.13.1"
	},
	devDependencies: {
		cypress: "^4.5.0",
		react: "^16.13.1",
		"start-server-and-test": "^1.11.0"
	}
};

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var Well$1 = function Well(_ref) {
  var tag = _ref.tag,
      children = _ref.children,
      componentOverrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["tag", "children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var defaultOverrides = {
    Well: defaultWell
  };

  var state = _objectSpread({
    tag: tag,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$W = _overrideReconciler.Well,
      Well = _overrideReconciler$W.component,
      wellStyles = _overrideReconciler$W.styles,
      wellAttributes = _overrideReconciler$W.attributes;

  return core.jsx(Well, _extends({}, rest, {
    state: state
  }, wellAttributes(state), {
    css: wellStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

Well$1.propTypes = {
  /**
   * Component tag
   */
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]).isRequired,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Well: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};
Well$1.defaultProps = {
  tag: 'div'
};

exports.Well = Well$1;
